API Reference
=============


Manager
-------

.. autoclass:: antidote.manager.DependencyManager
    :members:


Injector
--------

.. autoclass:: antidote.injector.DependencyInjector
    :members:


Container
---------

.. autoclass:: antidote.container.DependencyContainer
    :members:
    :special-members:
    :exclude-members: __dict__,__weakref__,__init__,__repr__,__str__

.. autoclass:: antidote.container.Dependency
    :members:

.. autoclass:: antidote.container.Instance
    :members:


Providers
---------

.. autoclass:: antidote.providers.factories.FactoryProvider
    :members:
    :special-members:
    :exclude-members: __dict__,__weakref__,__init__,__repr__


.. autoclass:: antidote.providers.parameters.ParameterProvider
    :members:
    :special-members:
    :exclude-members: __dict__,__weakref__,__init__,__repr__


Exceptions
----------

.. automodule:: antidote.exceptions
    :members:
